import { Component, OnInit, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Response } from '@angular/http';

import { Observable } from 'rxjs/Rx';
import { NgbActiveModal, NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { EventManager, AlertService } from 'ng-jhipster';

import { BlockTx } from './block-tx.model';
import { BlockTxPopupService } from './block-tx-popup.service';
import { BlockTxService } from './block-tx.service';

@Component({
    selector: 'jhi-block-tx-dialog',
    templateUrl: './block-tx-dialog.component.html'
})
export class BlockTxDialogComponent implements OnInit {

    blockTx: BlockTx;
    authorities: any[];
    isSaving: boolean;

    constructor(
        public activeModal: NgbActiveModal,
        private alertService: AlertService,
        private blockTxService: BlockTxService,
        private eventManager: EventManager
    ) {
    }

    ngOnInit() {
        this.isSaving = false;
        this.authorities = ['ROLE_USER', 'ROLE_ADMIN'];
    }
    clear() {
        this.activeModal.dismiss('cancel');
    }

    save() {
        this.isSaving = true;
        if (this.blockTx.id !== undefined) {
            this.subscribeToSaveResponse(
                this.blockTxService.update(this.blockTx), false);
        } else {
            this.subscribeToSaveResponse(
                this.blockTxService.create(this.blockTx), true);
        }
    }

    private subscribeToSaveResponse(result: Observable<BlockTx>, isCreated: boolean) {
        result.subscribe((res: BlockTx) =>
            this.onSaveSuccess(res, isCreated), (res: Response) => this.onSaveError(res));
    }

    private onSaveSuccess(result: BlockTx, isCreated: boolean) {
        this.alertService.success(
            isCreated ? 'beanHospitalApp.blockTx.created'
            : 'beanHospitalApp.blockTx.updated',
            { param : result.id }, null);

        this.eventManager.broadcast({ name: 'blockTxListModification', content: 'OK'});
        this.isSaving = false;
        this.activeModal.dismiss(result);
    }

    private onSaveError(error) {
        try {
            error.json();
        } catch (exception) {
            error.message = error.text();
        }
        this.isSaving = false;
        this.onError(error);
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}

@Component({
    selector: 'jhi-block-tx-popup',
    template: ''
})
export class BlockTxPopupComponent implements OnInit, OnDestroy {

    modalRef: NgbModalRef;
    routeSub: any;

    constructor(
        private route: ActivatedRoute,
        private blockTxPopupService: BlockTxPopupService
    ) {}

    ngOnInit() {
        this.routeSub = this.route.params.subscribe((params) => {
            if ( params['id'] ) {
                this.modalRef = this.blockTxPopupService
                    .open(BlockTxDialogComponent, params['id']);
            } else {
                this.modalRef = this.blockTxPopupService
                    .open(BlockTxDialogComponent);
            }
        });
    }

    ngOnDestroy() {
        this.routeSub.unsubscribe();
    }
}
