import { Injectable } from '@angular/core';
import { Resolve, ActivatedRouteSnapshot, RouterStateSnapshot, Routes, CanActivate } from '@angular/router';

import { UserRouteAccessService } from '../../../src/main/webapp/app/shared';
import { PaginationUtil } from 'ng-jhipster';

import { BlockTxComponent } from './block-tx.component';
import { BlockTxDetailComponent } from './block-tx-detail.component';
import { BlockTxPopupComponent } from './block-tx-dialog.component';
import { BlockTxDeletePopupComponent } from './block-tx-delete-dialog.component';
import { BlockTxMemoPopupComponent } from './block-tx-memo.component';

import { Principal } from '../../../src/main/webapp/app/shared';

@Injectable()
export class BlockTxResolvePagingParams implements Resolve<any> {

    constructor(private paginationUtil: PaginationUtil) {}

    resolve(route: ActivatedRouteSnapshot, state: RouterStateSnapshot) {
        const page = route.queryParams['page'] ? route.queryParams['page'] : '1';
        const sort = route.queryParams['sort'] ? route.queryParams['sort'] : 'txTime,desc';
        return {
            page: this.paginationUtil.parsePage(page),
            predicate: this.paginationUtil.parsePredicate(sort),
            ascending: this.paginationUtil.parseAscending(sort)
        };
    }
}

export const blockTxRoute: Routes = [
    {
        path: 'block-tx',
        component: BlockTxComponent,
        resolve: {
            'pagingParams': BlockTxResolvePagingParams
        },
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService]
    }, {
        path: 'block-tx/:id',
        component: BlockTxDetailComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService]
    }
];

export const blockTxPopupRoute: Routes = [
    {
        path: 'block-tx-new',
        component: BlockTxPopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'block-tx/:id/edit',
        component: BlockTxPopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'block-tx/:id/delete',
        component: BlockTxDeletePopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'block-tx/:id/memo',
        component: BlockTxMemoPopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'beanHospitalApp.blockTx.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    }
];
