import { Injectable } from '@angular/core';
import {BaseRequestOptions, Http, Response, URLSearchParams} from '@angular/http';
import { Observable } from 'rxjs/Rx';
import { DateUtils } from 'ng-jhipster';

import { BlockTx } from './block-tx.model';
import { ResponseWrapper, createRequestOption } from '../../../src/main/webapp/app/shared';
import {RemoteConf} from '../../../src/main/webapp/app/entities/remote-conf';

@Injectable()
export class BlockTxService {

    private resourceUrl = RemoteConf.domain + 'api/block-txes';
    private findUrl = RemoteConf.domain + 'api/v-bean-block-txes';

    constructor(private http: Http, private dateUtils: DateUtils) { }

    create(blockTx: BlockTx): Observable<BlockTx> {
        const copy = this.convert(blockTx);
        return this.http.post(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    update(blockTx: BlockTx): Observable<BlockTx> {
        const copy = this.convert(blockTx);
        return this.http.put(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    find(id: number): Observable<BlockTx> {
        return this.http.get(`${this.findUrl}/${id}`).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    searchMemo(memo: string, password: string): Observable<ResponseWrapper> {
        const options = new BaseRequestOptions();
        options.search = new URLSearchParams();
        options.search.set('memo', memo);
        options.search.set('password', password);
        return this.http.get('/api/memo', options)
            .map((res: Response) => this.convertResponse(res));
    }

    query(req?: any): Observable<ResponseWrapper> {
        const options = createRequestOption(req);
        options.search.set('account', RemoteConf.account);
        console.log(options);
        return this.http.get(this.findUrl, options)
            .map((res: Response) => this.convertResponse(res));
    }

    delete(id: number): Observable<Response> {
        return this.http.delete(`${this.resourceUrl}/${id}`);
    }

    search(req?: any): Observable<ResponseWrapper> {
        const options = createRequestOption(req);
        return this.http.get(this.findUrl, options)
            .map((res: any) => this.convertResponse(res));
    }

    private convertResponse(res: Response): ResponseWrapper {
        const jsonResponse = res.json();
        for (let i = 0; i < jsonResponse.length; i++) {
            this.convertItemFromServer(jsonResponse[i]);
        }
        return new ResponseWrapper(res.headers, jsonResponse);
    }

    private convertItemFromServer(entity: any) {
        entity.txTime = this.dateUtils
            .convertDateTimeFromServer(entity.txTime);
    }

    private convert(blockTx: BlockTx): BlockTx {
        const copy: BlockTx = Object.assign({}, blockTx);

        copy.txTime = this.dateUtils.toDate(blockTx.txTime);
        return copy;
    }
}
