import {Component, OnInit, OnDestroy} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {Response} from '@angular/http';

import {Observable} from 'rxjs/Rx';
import {NgbActiveModal, NgbModalRef} from '@ng-bootstrap/ng-bootstrap';
import {EventManager, AlertService} from 'ng-jhipster';

import {SvcBind} from './svc-bind.model';
import {SvcBindPopupService} from './svc-bind-popup.service';
import {SvcBindService} from './svc-bind.service';
import {RemoteConf} from '../../../src/main/webapp/app/entities/remote-conf';

@Component({
    selector: 'jhi-svc-bind-dialog',
    templateUrl: './svc-bind-dialog.component.html'
})
export class SvcBindDialogComponent implements OnInit {

    svcBind: SvcBind;
    oldSvcBind: SvcBind;
    authorities: any[];
    isSaving: boolean;
    isWarning: boolean;
    isModify: boolean;

    constructor(public activeModal: NgbActiveModal,
                private alertService: AlertService,
                private svcBindService: SvcBindService,
                private eventManager: EventManager) {
    }

    ngOnInit() {
        this.isSaving = false;
        this.isWarning = false;
        this.isModify = false;
        this.oldSvcBind = new SvcBind();
        this.oldSvcBind.fee = this.svcBind.fee;
        this.oldSvcBind.action = this.svcBind.action;
        this.authorities = ['ROLE_USER', 'ROLE_ADMIN'];
        const href = window.document.location.href;
        const patt = /\/\d+\(/;
        const result = patt.exec(href)[0];
        const svId = result.substr(1, result.length - 2);
        this.svcBind.svcId = parseInt(svId, 10);
        this.svcBind.bindAddr = RemoteConf.addr;
        console.log( svId );
    }

    clear() {
        this.activeModal.dismiss('cancel');
    }

    save() {
        this.isSaving = true;
        if (this.svcBind.id !== undefined) {
            this.subscribeToSaveResponse(
                this.svcBindService.update(this.svcBind), false);
        } else {
            this.subscribeToSaveResponse(
                this.svcBindService.create(this.svcBind), true);
        }
    }

    actionChange() {
        if (this.svcBind.action === 'u') {
            this.isWarning = true;
        } else {
            this.isWarning = false;
        }
        if (this.oldSvcBind.action === this.svcBind.action &&
            this.oldSvcBind.fee === this.svcBind.fee &&
            !(this.svcBind.action === 'b' || this.svcBind.action === 'u')) {
            this.isModify = false;
        } else {
            this.isModify = true;
        }
    }

    feeChange() {
        if (this.oldSvcBind.action === this.svcBind.action &&
            this.oldSvcBind.fee === this.svcBind.fee &&
            !(this.svcBind.action === 'b' || this.svcBind.action === 'u')) {
            this.isModify = false;
        } else {
            this.isModify = true;
        }
    }

    private subscribeToSaveResponse(result: Observable<SvcBind>, isCreated: boolean) {
        console.log(result);
        console.log(isCreated);
        result.subscribe((res: SvcBind) =>
            this.onSaveSuccess(res, isCreated), (res: Response) => this.onSaveError(res));
    }

    private onSaveSuccess(result: SvcBind, isCreated: boolean) {
        this.alertService.success(
            isCreated ? 'BeanDRGsApp.svcBind.created'
                : 'BeanDRGsApp.svcBind.updated',
            {param: result.id}, null);

        this.eventManager.broadcast({name: 'svcBindListModification', content: 'OK'});
        this.isSaving = false;
        this.activeModal.dismiss(result);
    }

    private onSaveError(error) {
        try {
            error.json();
        } catch (exception) {
            error.message = error.text();
        }
        this.isSaving = false;
        this.onError(error);
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}

@Component({
    selector: 'jhi-svc-bind-popup',
    template: ''
})
export class SvcBindPopupComponent implements OnInit, OnDestroy {

    modalRef: NgbModalRef;
    routeSub: any;

    constructor(private route: ActivatedRoute,
                private svcBindPopupService: SvcBindPopupService) {
    }

    ngOnInit() {
        this.routeSub = this.route.params.subscribe((params) => {
            if (params['id']) {
                this.modalRef = this.svcBindPopupService
                    .open(SvcBindDialogComponent, params['id']);
            } else {
                this.modalRef = this.svcBindPopupService
                    .open(SvcBindDialogComponent);
            }
        });
    }

    ngOnDestroy() {
        this.routeSub.unsubscribe();
    }
}
