import { Injectable, Component } from '@angular/core';
import { Router } from '@angular/router';
import { NgbModal, NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { DatePipe } from '@angular/common';
import { SvcBind } from './svc-bind.model';
import { SvcBindService } from './svc-bind.service';
@Injectable()
export class SvcBindPopupService {
    private isOpen = false;
    constructor(
        private datePipe: DatePipe,
        private modalService: NgbModal,
        private router: Router,
        private svcBindService: SvcBindService

    ) {}

    open(component: Component, id?: number | any): NgbModalRef {
        if (this.isOpen) {
            return;
        }
        this.isOpen = true;

        if (id) {
            this.svcBindService.find(id).subscribe((svcBind) => {
                svcBind.createtime = this.datePipe
                    .transform(svcBind.createtime, 'yyyy-MM-ddThh:mm');
                svcBind.updatetime = this.datePipe
                    .transform(svcBind.updatetime, 'yyyy-MM-ddThh:mm');
                this.svcBindModalRef(component, svcBind);
            });
        } else {
            return this.svcBindModalRef(component, new SvcBind());
        }
    }

    svcBindModalRef(component: Component, svcBind: SvcBind): NgbModalRef {
        const modalRef = this.modalService.open(component, { size: 'lg', backdrop: 'static'});
        modalRef.componentInstance.svcBind = svcBind;
        modalRef.result.then((result) => {
            this.router.navigate([{ outlets: { popup: null }}], { replaceUrl: true });
            this.isOpen = false;
        }, (reason) => {
            this.router.navigate([{ outlets: { popup: null }}], { replaceUrl: true });
            this.isOpen = false;
        });
        return modalRef;
    }
}
