import { Component, OnInit, OnDestroy } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Subscription } from 'rxjs/Rx';
import { EventManager, ParseLinks, PaginationUtil, JhiLanguageService, AlertService } from 'ng-jhipster';

import { SvcBind } from './svc-bind.model';
import { SvcBindService } from './svc-bind.service';
import { ITEMS_PER_PAGE, Principal} from '../../../src/main/webapp/app/shared';
import { ResponseWrapper } from '../../../src/main/webapp/app/shared';
import { PaginationConfig } from '../../../src/main/webapp/app/blocks/config/uib-pagination.config';

@Component({
    selector: 'jhi-svc-bind',
    templateUrl: './svc-bind.component.html'
})
export class SvcBindComponent implements OnInit, OnDestroy {
svcBinds: SvcBind[];
    currentAccount: any;
    eventSubscriber: Subscription;

    constructor(
        private svcBindService: SvcBindService,
        private alertService: AlertService,
        private eventManager: EventManager,
        private principal: Principal
    ) {
    }

    loadAll() {
        this.svcBindService.query().subscribe(
            (res: ResponseWrapper) => {
                this.svcBinds = res.json;
            },
            (res: ResponseWrapper) => this.onError(res.json)
        );
    }
    ngOnInit() {
        this.loadAll();
        this.principal.identity().then((account) => {
            this.currentAccount = account;
        });
        this.registerChangeInSvcBinds();
    }

    ngOnDestroy() {
        this.eventManager.destroy(this.eventSubscriber);
    }

    trackId(index: number, item: SvcBind) {
        return item.id;
    }
    registerChangeInSvcBinds() {
        this.eventSubscriber = this.eventManager.subscribe('svcBindListModification', (response) => this.loadAll());
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}
