import { Injectable } from '@angular/core';
import {Http, Response, Headers, RequestOptions} from '@angular/http';
import { Observable } from 'rxjs/Rx';
import { DateUtils } from 'ng-jhipster';

import { SvcBind } from './svc-bind.model';
import { ResponseWrapper, createRequestOption } from '../../../src/main/webapp/app/shared';
import { RemoteConf } from '../../../src/main/webapp/app/entities/remote-conf';

@Injectable()
export class SvcBindService {

    private resourceUrl = 'api/svc-binds';
    private findUrl = RemoteConf.domain + 'api/svc-binds';

    constructor(private http: Http, private dateUtils: DateUtils) {
    }

    create(svcBind: SvcBind): Observable<SvcBind> {
        const copy = this.convert(svcBind);
        return this.http.post(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    update(svcBind: SvcBind): Observable<SvcBind> {
        const copy = this.convert(svcBind);
        return this.http.put(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    find(id: number): Observable<SvcBind> {
        return this.http.get(`${this.findUrl}/${id}`).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    query(req?: any): Observable<ResponseWrapper> {
        const options = createRequestOption(req);
        return this.http.get(this.findUrl, options)
            .map((res: Response) => this.convertResponse(res));
    }

    delete(id: number): Observable<Response> {
        return this.http.delete(`${this.resourceUrl}/${id}`);
    }

    private convertResponse(res: Response): ResponseWrapper {
        const jsonResponse = res.json();
        for (let i = 0; i < jsonResponse.length; i++) {
            this.convertItemFromServer(jsonResponse[i]);
        }
        return new ResponseWrapper(res.headers, jsonResponse);
    }

    private convertItemFromServer(entity: any) {
        entity.createtime = this.dateUtils
            .convertDateTimeFromServer(entity.createtime);
        entity.updatetime = this.dateUtils
            .convertDateTimeFromServer(entity.updatetime);
    }

    private convert(svcBind: SvcBind): SvcBind {
        const copy: SvcBind = Object.assign({}, svcBind);

        copy.createtime = this.dateUtils.toDate(svcBind.createtime);

        copy.updatetime = this.dateUtils.toDate(svcBind.updatetime);
        return copy;
    }
}
