import { Component, OnInit, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs/Rx';
import {AlertService, EventManager} from 'ng-jhipster';

import { SvcDef } from './svc-def.model';
import { SvcDefService } from './svc-def.service';
import {Observable} from 'rxjs/Observable';
import {NgbActiveModal} from '@ng-bootstrap/ng-bootstrap';
import {RemoteConf} from '../../../src/main/webapp/app/entities/remote-conf';

@Component({
    selector: 'jhi-svc-def-detail',
    templateUrl: './svc-def-detail.component.html'
})
export class SvcDefDetailComponent implements OnInit, OnDestroy {

    svcDef: SvcDef;
    private subscription: Subscription;
    private eventSubscriber: Subscription;
    isEdit: boolean;
    account: string;

    constructor(
        private eventManager: EventManager,
        private alertService: AlertService,
        private svcDefService: SvcDefService,
        private route: ActivatedRoute
    ) {
        this.isEdit = false;
    }

    ngOnInit() {
        this.account = RemoteConf.account;
        this.subscription = this.route.params.subscribe((params) => {
            this.load(params['id']);
        });
        this.registerChangeInSvcDefs();
        this.registerChangeInSvcBinds();
    }

    load(id) {
        this.svcDefService.find(id).subscribe((svcDef) => {
            this.svcDef = svcDef;
        });
    }
    previousState() {
        window.history.back();
    }

    ngOnDestroy() {
        this.subscription.unsubscribe();
        this.eventManager.destroy(this.eventSubscriber);
    }

    registerChangeInSvcDefs() {
        this.eventSubscriber = this.eventManager.subscribe(
            'svcDefListModification',
            (response) => this.load(this.svcDef.id)
        );
    }

    registerChangeInSvcBinds() {
        this.eventSubscriber = this.eventManager.subscribe(
            'svcBindListModification',
            (response) => this.load(this.svcDef.id)
        );
    }

    edit() {
        if (this.isEdit) {
            this.isEdit = false;
        } else {
            this.isEdit = true;
        }
    }

    save() {
        const updateSvcDef: SvcDef = new SvcDef();
        updateSvcDef.id = this.svcDef.id;
        // updateSvcDef.fee = this.svcDef.fee;
        // updateSvcDef.svcBindAction = this.svcDef.svcBindAction;
        this.subscribeToSaveResponse(
            this.svcDefService.update(updateSvcDef), true);
    }

    private subscribeToSaveResponse(result: Observable<SvcDef>, isCreated: boolean) {
        result.subscribe((res: SvcDef) =>
            this.onSaveSuccess(res, isCreated), (res: Response) => this.onSaveError(res));
    }

    private onSaveSuccess(result: SvcDef, isCreated: boolean) {
        this.alertService.success(
            isCreated ? 'BeanDRGsApp.svcDef.created'
                : 'BeanDRGsApp.svcDef.updated',
            { param : result.id }, null);

        this.eventManager.broadcast({ name: 'svcDefListModification', content: 'OK'});
        this.isEdit = false;
    }

    private onSaveError(error) {
        try {
            error.json();
        } catch (exception) {
            error.message = error.text();
        }
        this.isEdit = false;
        this.onError(error);
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}
