import { Component, OnInit, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Response } from '@angular/http';

import { Observable } from 'rxjs/Rx';
import { NgbActiveModal, NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { EventManager, AlertService } from 'ng-jhipster';

import { SvcDef } from './svc-def.model';
import { SvcDefPopupService } from './svc-def-popup.service';
import { SvcDefService } from './svc-def.service';
import {RemoteConf} from '../../../src/main/webapp/app/entities/remote-conf';

@Component({
    selector: 'jhi-svc-def-dialog',
    templateUrl: './svc-def-dialog.component.html'
})
export class SvcDefDialogComponent implements OnInit {

    svcDef: SvcDef;
    authorities: any[];
    isSaving: boolean;

    constructor(
        public activeModal: NgbActiveModal,
        private alertService: AlertService,
        private svcDefService: SvcDefService,
        private eventManager: EventManager
    ) {
    }

    ngOnInit() {
        this.isSaving = false;
        this.authorities = ['ROLE_USER', 'ROLE_ADMIN'];
        // this.svcDef.defAddrName = RemoteConf.addr;
        this.svcDef.auth = '*';
    }
    clear() {
        this.activeModal.dismiss('cancel');
    }

    save() {
        this.isSaving = true;
        if (this.svcDef.id !== undefined) {
            this.subscribeToSaveResponse(
                this.svcDefService.update(this.svcDef), false);
        } else {
            this.subscribeToSaveResponse(
                this.svcDefService.create(this.svcDef), true);
        }
    }

    private subscribeToSaveResponse(result: Observable<SvcDef>, isCreated: boolean) {
        result.subscribe((res: SvcDef) =>
            this.onSaveSuccess(res, isCreated), (res: Response) => this.onSaveError(res));
    }

    private onSaveSuccess(result: SvcDef, isCreated: boolean) {
        this.alertService.success(
            isCreated ? 'BeanDRGsApp.svcDef.created'
            : 'BeanDRGsApp.svcDef.updated',
            { param : result.id }, null);

        this.eventManager.broadcast({ name: 'svcDefListModification', content: 'OK'});
        this.isSaving = false;
        this.activeModal.dismiss(result);
    }

    private onSaveError(error) {
        try {
            error.json();
        } catch (exception) {
            error.message = error.text();
        }
        this.isSaving = false;
        this.onError(error);
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}

@Component({
    selector: 'jhi-svc-def-popup',
    template: ''
})
export class SvcDefPopupComponent implements OnInit, OnDestroy {

    modalRef: NgbModalRef;
    routeSub: any;

    constructor(
        private route: ActivatedRoute,
        private svcDefPopupService: SvcDefPopupService
    ) {}

    ngOnInit() {
        this.routeSub = this.route.params.subscribe((params) => {
            if ( params['id'] ) {
                this.modalRef = this.svcDefPopupService
                    .open(SvcDefDialogComponent, params['id']);
            } else {
                this.modalRef = this.svcDefPopupService
                    .open(SvcDefDialogComponent);
            }
        });
    }

    ngOnDestroy() {
        this.routeSub.unsubscribe();
    }
}
