import { Injectable } from '@angular/core';
import { Resolve, ActivatedRouteSnapshot, RouterStateSnapshot, Routes, CanActivate } from '@angular/router';

import { UserRouteAccessService } from '../../../src/main/webapp/app/shared';
import { PaginationUtil } from 'ng-jhipster';

import { SvcDefComponent } from './svc-def.component';
import { SvcDefDetailComponent } from './svc-def-detail.component';
import { SvcDefPopupComponent } from './svc-def-dialog.component';
import { SvcDefDeletePopupComponent } from './svc-def-delete-dialog.component';

import { Principal } from '../../../src/main/webapp/app/shared';
import {SvcDefUpdatePopupComponent} from './svc-def-update-dialog.component';

@Injectable()
export class SvcDefResolvePagingParams implements Resolve<any> {

    constructor(private paginationUtil: PaginationUtil) {}

    resolve(route: ActivatedRouteSnapshot, state: RouterStateSnapshot) {
        const page = route.queryParams['page'] ? route.queryParams['page'] : '1';
        const sort = route.queryParams['sort'] ? route.queryParams['sort'] : 'id,asc';
        return {
            page: this.paginationUtil.parsePage(page),
            predicate: this.paginationUtil.parsePredicate(sort),
            ascending: this.paginationUtil.parseAscending(sort)
      };
    }
}

export const svcDefRoute: Routes = [
    {
        path: 'svc-def',
        component: SvcDefComponent,
        resolve: {
            'pagingParams': SvcDefResolvePagingParams
        },
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService]
    }, {
        path: 'svc-def/:id',
        component: SvcDefDetailComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService]
    }
];

export const svcDefPopupRoute: Routes = [
    {
        path: 'svc-def-new',
        component: SvcDefPopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'svc-def/:id/edit',
        component: SvcDefPopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'svc-def/:id/delete',
        component: SvcDefDeletePopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    },
    {
        path: 'svc-def/:id/update?',
        component: SvcDefUpdatePopupComponent,
        data: {
            authorities: ['ROLE_USER'],
            pageTitle: 'BeanDRGsApp.svcDef.home.title'
        },
        canActivate: [UserRouteAccessService],
        outlet: 'popup'
    }
];
