import {Injectable} from '@angular/core';
import {Http, RequestOptions, Headers, Response} from '@angular/http';
import {Observable} from 'rxjs/Rx';
import {DateUtils} from 'ng-jhipster';

import {SvcDef} from './svc-def.model';
import { ResponseWrapper, createRequestOption } from '../../../src/main/webapp/app/shared';
import {RemoteConf} from '../../../src/main/webapp/app/entities/remote-conf';

@Injectable()
export class SvcDefService {

    private resourceUrl = 'api/svc-defs';
    private findUrl = RemoteConf.domain + 'api/v-bean-svc-defs';

    constructor(private http: Http, private dateUtils: DateUtils) {
    }

    create(svcDef: SvcDef): Observable<SvcDef> {
        const copy = this.convert(svcDef);
        return this.http.post(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    update(svcDef: SvcDef): Observable<SvcDef> {
        const copy = this.convert(svcDef);
        return this.http.put(this.resourceUrl, copy).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    find(id: number): Observable<SvcDef> {
        return this.http.get(`${this.findUrl}/${id}`).map((res: Response) => {
            const jsonResponse = res.json();
            this.convertItemFromServer(jsonResponse);
            return jsonResponse;
        });
    }

    query(req?: any): Observable<ResponseWrapper> {
        const options = createRequestOption(req);
        // 查询自己定义的服务传入addr
        // options.search.set('addr', RemoteConf.addr);
        return this.http.get(this.findUrl, options)
            .map((res: Response) => this.convertResponse(res));
    }

    delete(id: number): Observable<Response> {
        return this.http.delete(`${this.resourceUrl}/${id}`);
    }

    private convertResponse(res: Response): ResponseWrapper {
        const jsonResponse = res.json();
        for (let i = 0; i < jsonResponse.length; i++) {
            this.convertItemFromServer(jsonResponse[i]);
        }
        return new ResponseWrapper(res.headers, jsonResponse);
    }

    private convertItemFromServer(entity: any) {
        entity.createtime = this.dateUtils
            .convertDateTimeFromServer(entity.createtime);
        entity.updatetime = this.dateUtils
            .convertDateTimeFromServer(entity.updatetime);
    }

    private convert(svcDef: SvcDef): SvcDef {
        const copy: SvcDef = Object.assign({}, svcDef);

        copy.createtime = this.dateUtils.toDate(svcDef.createtime);

        copy.updatetime = this.dateUtils.toDate(svcDef.updatetime);
        return copy;
    }
}
